==> tuia-treasure-center-api-0.0.3-zwb4-20180510.115103-1-sources.jar: cn/tuia/tuia/treasure/center/api/dto/ArticleDto.java <==
package cn.tuia.tuia.treasure.center.api.dto;


import java.util.Date;
import java.util.List;

/**
 * Created by zhou_wb on 2018/5/6.
 */
public class ArticleDto {

    /**
     * 文章Id
     */
    private Long id;

    /**
     * 文章缩略图
     */
    private String  headImgUrl;

    /**
     * 昵称
     */
    private String nickName;

    /**
     * 文章标题
     */
    private String title;

    /**
     * 文章摘要
     */
    private String articleAbstract;

    /**
     * 账号
     */
    private Long accountId;

    /**
     * 文章标签
     */
    private String tags;

    /**
     * 文章url
     */
    private String url;


    /**
     * 文章状态
     */
    private Integer articleStatus;


    /**
     * 文章来源
     */
    private Integer articleSource;

    /**
     * 是否置顶
     */
    private Integer isStick;

    /**
     * 下线原因
     */
    private String offLineReason;

    /**
     * 下线时间
     */
    private Date gmtOffLine;


    /**
     * 发布时间
     */
    private Date gmtPublish;

    /**
     * 入库当前时间
     */
    private Date curDate;


    /**
     * 创建时间
     */
    private Date gmtCreate;

    /**
     * 修改时间
     */
    private Date gmtModifyied;

    /**
     * 标签内容
     */
    private List<String> tagsContent;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getHeadImgUrl() {
        return headImgUrl;
    }

    public void setHeadImgUrl(String headImgUrl) {
        this.headImgUrl = headImgUrl;
    }

    public String getNickName() {
        return nickName;
    }

    public void setNickName(String nickName) {
        this.nickName = nickName;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getArticleAbstract() {
        return articleAbstract;
    }

    public void setArticleAbstract(String articleAbstract) {
        this.articleAbstract = articleAbstract;
    }

    public Long getAccountId() {
        return accountId;
    }

    public void setAccountId(Long accountId) {
        this.accountId = accountId;
    }

    public String getTags() {
        return tags;
    }

    public void setTags(String tags) {
        this.tags = tags;
    }

    public String getUrl() {
        return url;
    }

    public void setUrl(String url) {
        this.url = url;
    }

    public Integer getArticleStatus() {
        return articleStatus;
    }

    public void setArticleStatus(Integer articleStatus) {
        this.articleStatus = articleStatus;
    }

    public Integer getArticleSource() {
        return articleSource;
    }

    public void setArticleSource(Integer articleSource) {
        this.articleSource = articleSource;
    }

    public Integer getIsStick() {
        return isStick;
    }

    public void setIsStick(Integer isStick) {
        this.isStick = isStick;
    }

    public String getOffLineReason() {
        return offLineReason;
    }

    public void setOffLineReason(String offLineReason) {
        this.offLineReason = offLineReason;
    }

    public Date getGmtOffLine() {
        return gmtOffLine;
    }

    public void setGmtOffLine(Date gmtOffLine) {
        this.gmtOffLine = gmtOffLine;
    }

    public Date getGmtPublish() {
        return gmtPublish;
    }

    public void setGmtPublish(Date gmtPublish) {
        this.gmtPublish = gmtPublish;
    }

    public Date getCurDate() {
        return curDate;
    }

    public void setCurDate(Date curDate) {
        this.curDate = curDate;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModifyied() {
        return gmtModifyied;
    }

    public void setGmtModifyied(Date gmtModifyied) {
        this.gmtModifyied = gmtModifyied;
    }

    public List<String> getTagsContent() {
        return tagsContent;
    }

    public void setTagsContent(List<String> tagsContent) {
        this.tagsContent = tagsContent;
    }
}

==> tuia-treasure-center-api-0.0.6.zwb16-20180606.151650-1-sources.jar: cn/tuia/tuia/treasure/center/api/dto/ArticleDto.java <==
package cn.tuia.tuia.treasure.center.api.dto;


import java.util.Date;
import java.util.List;

/**
 * Created by zhou_wb on 2018/5/6.
 */
public class ArticleDto {

    /**
     * 文章Id
     */
    private Long id;

    /**
     * 文章缩略图
     */
    private String  headImgUrl;

    /**
     * 昵称
     */
    private String nickName;

    /**
     * 文章标题
     */
    private String title;

    /**
     * 文章摘要
     */
    private String articleAbstract;

    /**
     * 账号
     */
    private Long accountId;

    /**
     * 文章标签
     */
    private String tags;

    /**
     * 文章url
     */
    private String url;


    /**
     * 文章状态
     */
    private Integer articleStatus;


    /**
     * 文章来源
     */
    private Integer articleSource;

    /**
     * 是否置顶
     */
    private Integer isStick;

    /**
     * 下线原因
     */
    private String offLineReason;

    /**
     * 下线时间
     */
    private Date gmtOffLine;


    /**
     * 发布时间
     */
    private Date gmtPublish;

    /**
     * 入库当前时间
     */
    private Date curDate;


    /**
     * 创建时间
     */
    private Date gmtCreate;

    /**
     * 修改时间
     */
    private Date gmtModified;

    /**
     * 标签内容
     */
    private List<String> tagsContent;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getHeadImgUrl() {
        return headImgUrl;
    }

    public void setHeadImgUrl(String headImgUrl) {
        this.headImgUrl = headImgUrl;
    }

    public String getNickName() {
        return nickName;
    }

    public void setNickName(String nickName) {
        this.nickName = nickName;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getArticleAbstract() {
        return articleAbstract;
    }

    public void setArticleAbstract(String articleAbstract) {
        this.articleAbstract = articleAbstract;
    }

    public Long getAccountId() {
        return accountId;
    }

    public void setAccountId(Long accountId) {
        this.accountId = accountId;
    }

    public String getTags() {
        return tags;
    }

    public void setTags(String tags) {
        this.tags = tags;
    }

    public String getUrl() {
        return url;
    }

    public void setUrl(String url) {
        this.url = url;
    }

    public Integer getArticleStatus() {
        return articleStatus;
    }

    public void setArticleStatus(Integer articleStatus) {
        this.articleStatus = articleStatus;
    }

    public Integer getArticleSource() {
        return articleSource;
    }

    public void setArticleSource(Integer articleSource) {
        this.articleSource = articleSource;
    }

    public Integer getIsStick() {
        return isStick;
    }

    public void setIsStick(Integer isStick) {
        this.isStick = isStick;
    }

    public String getOffLineReason() {
        return offLineReason;
    }

    public void setOffLineReason(String offLineReason) {
        this.offLineReason = offLineReason;
    }

    public Date getGmtOffLine() {
        return gmtOffLine;
    }

    public void setGmtOffLine(Date gmtOffLine) {
        this.gmtOffLine = gmtOffLine;
    }

    public Date getGmtPublish() {
        return gmtPublish;
    }

    public void setGmtPublish(Date gmtPublish) {
        this.gmtPublish = gmtPublish;
    }

    public Date getCurDate() {
        return curDate;
    }

    public void setCurDate(Date curDate) {
        this.curDate = curDate;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public List<String> getTagsContent() {
        return tagsContent;
    }

    public void setTagsContent(List<String> tagsContent) {
        this.tagsContent = tagsContent;
    }
}
